#ifndef __GRAPHICS_H__
#define __GRAPHICS_H__
#include <SDL.h>
#include <glib.h>
extern SDL_Surface *screen;
extern int gfx_init(void);
extern void gfx_update(int x, int y, int w, int h);
extern void gfx_done(void);
extern void gfx_draw_text(const char *txt, int x, int y, int size);
extern void gfx_clear(int x, int y, int w, int h);

extern void gfx_draw(SDL_Surface *pixmap, int x, int y);

gint gi_gems_pixbuf[7];
gint gi_tiles_bg_pixbuf[2];
gint gi_cursor_pixbuf;
gint gi_small_charset_pixbuf[50];
gint gi_medium_charset_pixbuf[50];
gint gi_big_charset_pixbuf[50];

#define SMALL_FONT_WIDTH	24
#define SMALL_FONT_HEIGHT	20

#define MEDIUM_FONT_WIDTH	36
#define MEDIUM_FONT_HEIGHT	30

#define BIG_FONT_WIDTH		48
#define BIG_FONT_HEIGHT		40

#define SMALL_FONT	0
#define MEDIUM_FONT	1
#define BIG_FONT	2


extern gint gi_gems_pixbuf[7];
extern gint gi_tiles_bg_pixbuf[2];
extern gint gi_cursor_pixbuf;
extern gint gi_small_charset_pixbuf[];
extern gint gi_not_pixbuf;
extern gint gi_power_pixbuf;

extern signed char gpc_font_glyphs[];

#endif
